Acoustics Hardware
==================

This Python package provides a unified interface to serveral hardware platforms used in acoustic measurements, e.g. audio interfaces.
The purpose of this package is twofold, both to enable cross-hardware interactions with a consistent interface, and to simplify scripting of advanced measurement setups.

Documentation:
    http://acoustics-hardware.readthedocs.io/
Source code and issue tracker:
    https://github.com/AppliedAcousticsChalmers/acoustics-hardware